Enum hdrsample::AdditionError
[−]
[src]
pub enum AdditionError {
OtherAddendValueExceedsRange,
ResizeFailedUsizeTypeTooSmall,
}Errors that can occur when adding another histogram.
Variants
OtherAddendValueExceedsRangeThe other histogram includes values that do not fit in this histogram's range. Only possible when auto resize is disabled.
ResizeFailedUsizeTypeTooSmallThe other histogram includes values that would map to indexes in this histogram that are
not expressible for usize. Configure this histogram to use fewer significant digits. Only
possible when resize is enabled.