Trait hdrsample::iterators::PickyIterator [] [src]

pub trait PickyIterator<T: Num + ToPrimitive + Copy> {
    fn pick(&mut self, usize, i64) -> bool;
    fn more(&mut self, usize) -> bool;
}

A trait for designing an subset iterator over values in a Histogram.

Required Methods

fn pick(&mut self, usize, i64) -> bool

should an item be yielded for the given index?

fn more(&mut self, usize) -> bool

should we keep iterating even though all future indices are zeros?

Implementors